/***************************************************************************
                          asciiselect.h  -  description
                             -------------------
    begin                : Mon Apr 24 2000
    copyright            : (C) 2000 by Hongli Lai
    email                : hongli@telekabel.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _ASCIISELECT_C_
#define _ASCIISELECT_C_

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <gnome.h>

gboolean InsertAsciiCharacterClick (GtkWidget *widget, gpointer gdata);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* ASCIISELECT */
